# LT pylib

[![Build Status](https://travis-ci.org/lancethomps/ltpylib.svg?branch=master)](https://travis-ci.org/lancethomps/ltpylib)

A Python library that exposes some commonly used helper functions.
